@@ -25,7 +25,7 @@ DEALINGS IN THE SOFTWARE.
 
 import types
 from collections import namedtuple
-from typing import TYPE_CHECKING, Any, ClassVar, Dict, List, Optional, Type, TypeVar
+from typing import TYPE_CHECKING, Any, ClassVar, Dict, List, Optional, Type, TypeVar, Union
 
 __all__ = (
     "Enum",
@@ -186,7 +186,6 @@ class ChannelType(Enum):
     group = 3
     category = 4
     news = 5
-    store = 6
     news_thread = 10
     public_thread = 11
     private_thread = 12
@@ -651,6 +650,13 @@ class SlashCommandOptionType(Enum):
             else:
                 raise TypeError("Invalid usage of typing.Union")
 
+        py_3_10_union_type = hasattr(types, "UnionType") and isinstance(datatype, types.UnionType)
+
+        if py_3_10_union_type or getattr(datatype, "__origin__", None) is Union:
+            # Python 3.10+ "|" operator or typing.Union has been used. The __args__ attribute is a tuple of the types.
+            # Type checking fails for this case, so ignore it.
+            return cls.from_datatype(datatype.__args__)  # type: ignore
+
         if datatype.__name__ in ["Member", "User"]:
             return cls.user
         if datatype.__name__ in [
