@@ -8,13 +8,14 @@ import  asyncio
 import  _discord as discord
 from    .tracing import *
 from    . import core
-
+from    . import message
 
 
 #######################################################################
 # Globals
 #######################################################################
-m_client                 = None     # Pycord Client object
+class GLOBALS:
+    client = None     # Pycord Client object
 
 __all__ = (
     "CLIENT",
@@ -34,26 +35,15 @@ class CLIENT(discord.Client):
             Info : Tasks that is started by pycord when you have been
                    successfully logged into discord.
         """
-        trace(f"Logged in as {self.user}", TraceLEVELS.NORMAL)
-
-        if core.GLOBALS.user_callback is not None:   # If user callback function was specified
-            await core.GLOBALS.user_callback() # Call user provided function after framework has started
-
-        if await core.initialize():
-            # Initialization was successful, so create the advertiser task and start advertising.
-            trace("Successful initialization!",TraceLEVELS.NORMAL)
-            asyncio.gather(
-                # Tasks for sending text messages/voice messages
-                asyncio.create_task(core.advertiser("text")),
-                asyncio.create_task(core.advertiser("voice"))
-            )
-        else:
-            # Initialization failed, close everything
-            await core.shutdown()
-
+        trace(f"[CLIENT]: Logged in as {self.user}", TraceLEVELS.NORMAL)
+        
+        # Initialize all the modules from the core module
+        asyncio.create_task(core.initialize())
+        
 
 def initialize(token: str, *,
-               bot: bool):
+               bot: bool,
+               intents: discord.Intents) -> bool:
     """
         ~  initialize  ~
         @Param:
@@ -64,12 +54,10 @@ def initialize(token: str, *,
         @Info:
         The function initializes Pycord, the discord API wrapper.
     """
-    global m_client
-    intents = discord.Intents.all()
-    m_client = CLIENT(intents=intents)
+    GLOBALS.client = CLIENT(intents=intents)
     if not bot:
-        trace("Bot is an user account which is against discord's ToS",TraceLEVELS.WARNING)
-    m_client.run(token, bot=bot)
+        trace("[CLIENT]: Bot is an user account which is against discord's ToS",TraceLEVELS.WARNING)
+    GLOBALS.client.run(token, bot=bot)
 
 
 def get_client() -> CLIENT:
@@ -80,4 +68,4 @@ def get_client() -> CLIENT:
     Info:   Returns the client object used by the framework,
             so the user wouldn't have to run 2 clients.
     """
-    return m_client
+    return GLOBALS.client
